Convert scholarly identifiers across registries, for example from PMID to DOI.
Usage
id_convert(
x,
to = scholidonline_types(),
from = NULL,
provider = c("auto", .scholidonline_providers()),
...,
quiet = FALSE
)Arguments
- x
A character vector of scholarly identifiers.
- to
A single target identifier type string, such as
"doi"or"pmid". Seescholidonline_types()for all supported values.- from
A single source identifier type string, or
NULLto infer the source type for each element ofx.- provider
A single provider string specifying which online service to use for the conversion. Use
"auto"to use the default provider for the requested conversion. In most cases,"auto"is appropriate.- ...
Reserved for future provider-specific arguments.
- quiet
A single logical value; if
TRUE, suppress provider warnings and messages where possible.